@@ -20,17 +20,10 @@
   | - Jonathan Tansavatdi                                                |
   +----------------------------------------------------------------------+
 */
+#include "php.h"
+
 extern zend_class_entry *amqp_channel_class_entry;
 
-void php_amqp_close_channel(amqp_channel_resource *channel_resource, zend_bool check_errors TSRMLS_DC);
+void php_amqp_close_channel(amqp_channel_resource *channel_resource, bool throw);
 
 PHP_MINIT_FUNCTION(amqp_channel);
-
-/*
-*Local variables:
-*tab-width: 4
-*c-basic-offset: 4
-*End:
-*vim600: noet sw=4 ts=4 fdm=marker
-*vim<600: noet sw=4 ts=4
-*/
