@@ -20,25 +20,10 @@
   | - Jonathan Tansavatdi                                                |
   +----------------------------------------------------------------------+
 */
-
-#if PHP_MAJOR_VERSION >= 7
-        #include "php7_support.h"
-#else
-        #include "php5_support.h"
-#endif
+#include "php_amqp.h"
 
 extern zend_class_entry *amqp_envelope_class_entry;
 
-void convert_amqp_envelope_to_zval(amqp_envelope_t *amqp_envelope, zval *envelope TSRMLS_DC);
+void convert_amqp_envelope_to_zval(amqp_envelope_t *amqp_envelope, zval *envelope);
 
 PHP_MINIT_FUNCTION(amqp_envelope);
-
-
-/*
-*Local variables:
-*tab-width: 4
-*c-basic-offset: 4
-*End:
-*vim600: noet sw=4 ts=4 fdm=marker
-*vim<600: noet sw=4 ts=4
-*/
