@@ -20,16 +20,8 @@
   | - Jonathan Tansavatdi                                                |
   +----------------------------------------------------------------------+
 */
+#include "php.h"
+
 extern zend_class_entry *amqp_exchange_class_entry;
 
-
 PHP_MINIT_FUNCTION(amqp_exchange);
-
-/*
-*Local variables:
-*tab-width: 4
-*c-basic-offset: 4
-*End:
-*vim600: noet sw=4 ts=4 fdm=marker
-*vim<600: noet sw=4 ts=4
-*/
